@@ -1,4 +1,4 @@
-from config import config
+from geoAnalytics.config import config
 import psycopg2
 import pandas as pd
 from geoAnalytics import csv2raster as c2r
@@ -67,12 +67,12 @@ class database:
             os.remove("temp_" + filename)
         
     def deleteTable(tableName):
-        delete_table = "delete table " + tableName + ";"
+        delete_table = "drop table " + tableName + ";"
         database.curr.execute(delete_table)
         database.conn.commit()
         
     def cloneTable(tableName, cloneTableName):
-        clone_table = "create table " + cloneTableName + "as (select * from " + tableName + ");"
+        clone_table = "create table " + cloneTableName + " as (select * from " + tableName + ");"
         database.curr.execute(clone_table)
         database.conn.commit()
         
